### Statistical Distribution Package

> **Smart-dist** is a package that contains code for processing Statistical Distribution as well as a Crypto Analysis  
  
<br/><br/>


|Crypto Chart||
|--|--|
|![473D53FD-6C4D-4A46-89D6-B810F8015DB2](https://user-images.githubusercontent.com/70070334/136704293-e3d8290c-dff6-4158-ae94-6ded81b1bf9e.jpeg)|![75270875-19BA-405E-81B5-E5B9B66DB100](https://user-images.githubusercontent.com/70070334/136704295-30e050d4-7364-4686-bc30-9be49d3da4eb.jpeg)|


|Gaussian Distribution| Probability Density Function | Binomial Distribution |
|--|--|--|
|![gauss_dist](https://user-images.githubusercontent.com/70070334/136705128-f450b393-27e2-4dfa-8308-579efa113dac.jpeg)|![prob_dist](https://upload.wikimedia.org/wikipedia/commons/thumb/1/1a/Boxplot_vs_PDF.svg/350px-Boxplot_vs_PDF.svg.png)| ![bino_dist](https://upload.wikimedia.org/wikipedia/commons/thumb/7/75/Binomial_distribution_pmf.svg/300px-Binomial_distribution_pmf.svg.png)


#### Credit:
Statistical Distribution package highly influenced by work from Udacity.  
[Udacity's AWS ML SCHOLARSHIP](https://www.udacity.com/scholarships/aws-machine-learning-scholarship-program)
